==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebDropdownItemComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemDescriptionMetadata } from "./WebDropdownItemDescriptionMetadata";
import { WebDropdownItemComponentEventArgsDescription } from "./WebDropdownItemComponentEventArgsDescription";
/**
 * @hidden
 */
export let WebDropdownItemComponentEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDropdownItemComponentEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebDropdownItemComponentEventArgsDescriptionMetadata.a == null) {
                WebDropdownItemComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDropdownItemComponentEventArgsDescriptionMetadata.c(WebDropdownItemComponentEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebDropdownItemComponentEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebDropdownItemComponentEventArgsDescriptionMetadata.a);
            WebDropdownItemDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DropdownItemComponentEventArgs");
            a.item("Detail", "ExportedType:WebDropdownItem");
        }
        static d(a) {
            WebDropdownItemComponentEventArgsDescriptionMetadata.b(a);
            a.aa("WebDropdownItemComponentEventArgs", () => new WebDropdownItemComponentEventArgsDescription());
            a.z("WebDropdownItemComponentEventArgs", WebDropdownItemComponentEventArgsDescriptionMetadata.a);
        }
    }
    WebDropdownItemComponentEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDropdownItemComponentEventArgsDescriptionMetadata, 'WebDropdownItemComponentEventArgsDescriptionMetadata');
    WebDropdownItemComponentEventArgsDescriptionMetadata.a = null;
    return WebDropdownItemComponentEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebDropdownItemComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemDescriptionMetadata } from "./WebDropdownItemDescriptionMetadata";
import { WebDropdownItemComponentEventArgsDescription } from "./WebDropdownItemComponentEventArgsDescription";
/**
 * @hidden
 */
export let WebDropdownItemComponentEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDropdownItemComponentEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebDropdownItemComponentEventArgsDescriptionMetadata.a == null) {
                WebDropdownItemComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDropdownItemComponentEventArgsDescriptionMetadata.c(WebDropdownItemComponentEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebDropdownItemComponentEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebDropdownItemComponentEventArgsDescriptionMetadata.a);
            WebDropdownItemDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DropdownItemComponentEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Detail", "ExportedType:WebDropdownItem");
        }
        static d(a) {
            WebDropdownItemComponentEventArgsDescriptionMetadata.b(a);
            a.ac("WebDropdownItemComponentEventArgs", () => new WebDropdownItemComponentEventArgsDescription());
            a.ab("WebDropdownItemComponentEventArgs", WebDropdownItemComponentEventArgsDescriptionMetadata.a);
        }
    }
    WebDropdownItemComponentEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDropdownItemComponentEventArgsDescriptionMetadata, 'WebDropdownItemComponentEventArgsDescriptionMetadata');
    WebDropdownItemComponentEventArgsDescriptionMetadata.a = null;
    return WebDropdownItemComponentEventArgsDescriptionMetadata;
})();
